@@ -115,8 +115,13 @@ bool ChewingLargeTable2::load_text(FILE * infile, TABLE_PHONETIC_TYPE type) {
     size_t freq;
 
     while (!feof(infile)) {
+#ifdef __APPLE__
+        int num = fscanf(infile, "%255s %255[^ \t] %u %ld",
+                         pinyin, phrase, &token, &freq);
+#else
         int num = fscanf(infile, "%255s %255s %u %ld",
                          pinyin, phrase, &token, &freq);
+#endif
 
         if (4 != num)
             continue;
@@ -149,7 +154,7 @@ bool ChewingLargeTable2::load_text(FILE * infile, TABLE_PHONETIC_TYPE type) {
         };
 
         if (len != keys->len) {
-            fprintf(stderr, "ChewingLargeTable::load_text:%s\t%s\t%u\t%ld\n",
+            fprintf(stderr, "ChewingLargeTable2::load_text:%s\t%s\t%u\t%ld\n",
                     pinyin, phrase, token, freq);
             continue;
         }
